@@ -5,6 +5,7 @@
 from google_images_search import GoogleImagesSearch
 from dotenv import load_dotenv
 import os
+# Windows user : pip install windows-curses 
 
 # Once you've created them, save your API and CX / make an .env file in this format :
 # export DEVELOPER_KEY=QIzaSyD9G993bcg2049OxR0d9KOZNkjo8AdkMJc
@@ -15,6 +16,12 @@ if os.path.exists(".env"):
   load_dotenv()
 else:
   print(".env file missing, please create one with your API and CX")
+  print("example format :\n")
+  print("export DEVELOPER_KEY=QIzaSyD9G993bcg2049OxR0d9KOZNkjo8AdkMJc")
+  print("export CX=9e25cccedd0ad4433\n")
+  print("Visit : https://console.developers.google.com for info\n")
+
+
 
 # create an 'ims' sub directory if it doesn't already exists
 if not os.path.exists('images/'):
@@ -46,4 +53,3 @@ def fetch_images(searchfor):
         }
     gis.search(search_params=_search_params, path_to_dir=spath)
 
-  print("Finished!")
